@@ -15,6 +15,7 @@ from docker.models.containers import Container
 from redisbench_admin.run.common import (
     get_start_time_vars,
     prepare_benchmark_parameters,
+    execute_init_commands,
 )
 from redisbench_admin.run.redistimeseries import timeseries_test_sucess_flow
 from redisbench_admin.run.run import calculate_client_tool_duration_and_check
@@ -23,7 +24,6 @@ from redisbench_admin.utils.benchmark_config import (
 )
 from redisbench_admin.utils.local import get_local_run_full_filename
 from redisbench_admin.utils.results import post_process_benchmark_results
-from redistimeseries.client import Client
 
 from redis_benchmarks_specification.__common__.env import (
     LOG_FORMAT,
@@ -79,7 +79,7 @@ def main():
         )
     )
 
-    rts = None
+    datasink_conn = None
     if args.datasink_push_results_redistimeseries:
         logging.info(
             "Checking redistimeseries datasink connection is available at: {}:{} to push the timeseries data".format(
@@ -87,7 +87,7 @@ def main():
             )
         )
         try:
-            rts = Client(
+            datasink_conn = redis.StrictRedis(
                 host=args.datasink_redistimeseries_host,
                 port=args.datasink_redistimeseries_port,
                 decode_responses=True,
@@ -97,8 +97,8 @@ def main():
                 socket_connect_timeout=REDIS_SOCKET_TIMEOUT,
                 socket_keepalive=True,
             )
-            rts.redis.ping()
-            rts.redis.client_setname(project_name_suffix)
+            datasink_conn.ping()
+            datasink_conn.client_setname(project_name_suffix)
         except redis.exceptions.ConnectionError as e:
             logging.error(
                 "Unable to connect to redis available at: {}:{}".format(
@@ -125,7 +125,7 @@ def main():
         docker_client,
         home,
         None,
-        rts,
+        datasink_conn,
         testsuite_spec_files,
         {},
         running_platform,
@@ -185,7 +185,7 @@ def process_self_contained_coordinator_stream(
     docker_client,
     home,
     newTestInfo,
-    rts,
+    datasink_conn,
     testsuite_spec_files,
     topologies_map,
     running_platform,
@@ -293,6 +293,10 @@ def process_self_contained_coordinator_stream(
                             test_tls_cacert,
                         )
 
+                    execute_init_commands(
+                        benchmark_config, r, dbconfig_keyname="dbconfig"
+                    )
+
                     benchmark_tool = extract_client_tool(benchmark_config)
                     # backwards compatible
                     if benchmark_tool is None:
@@ -431,7 +435,7 @@ def process_self_contained_coordinator_stream(
                         setup_type,
                         None,
                         results_dict,
-                        rts,
+                        datasink_conn,
                         datapoint_time_ms,
                         test_name,
                         git_branch,
